@@ -2,10 +2,11 @@ import subprocess
 import os
 from sys import version_info
 MAJOR=3
-MINOR=0
-PATCH=6
+MINOR=1
+PATCH=0
 VERSION="{MAJOR}.{MINOR}.{PATCH}".format(MAJOR=MAJOR, MINOR=MINOR, PATCH=PATCH)
 
+ADVANCED_VERSION = VERSION
 BRANCH="master"
 COMMIT=None
 AHEAD=0
@@ -36,6 +37,16 @@ def get_more_info():
     finally:
         os.chdir(old_cwd)
 
+def get_version():
+    global ADVANCED_VERSION
+    get_more_info()
+    ADVANCED_VERSION ="{vers}-{ahead}-{commit}-{branch}".format(
+            vers=VERSION, ahead=AHEAD, 
+            commit="release_commit" if COMMIT is None else COMMIT,
+            branch=BRANCH)
+    return ADVANCED_VERSION
+
+
 def mod_string(string):
     if (version_info > (3, 0)):
         return string.decode()
