@@ -50,7 +50,7 @@ def main(CMD=None, snakemake=None):
         exit(2)
     try:
         if not args.use_conda_default:
-            prefix = os.path.join(covpipe_default_location, args.name)
+            prefix = args.prefix or os.path.join(covpipe_default_location, args.name)
             print("Checking Environment Availability:\n", prefix)
         tool_availability()
         has_conda, parsed_prefix, found_pangolin = (
@@ -202,6 +202,10 @@ def git_manual_update(prefix):
             except subprocess.CalledProcessError as e:
                 print(e.output)
                 raise 
+            run_unsafe_command_in_pangolin(
+                    prefix,
+                    "python -m pip install {git} --upgrade".format(
+                        git="git+https://github.com/cov-lineages/constellations.git"))
             print("Updating PangoLearn...")
             run_unsafe_command_in_pangolin(
                     prefix,
